SockMap

Struct SockMap 

pub struct SockMap<T> { /* private fields */ }
An array of TCP or UDP sockets.

A SockMap is used to store TCP or UDP sockets. eBPF programs can then be attached to the map to inspect, filter or redirect network buffers on those sockets.

A SockMap can also be used to redirect packets to sockets contained by the map using bpf_redirect_map(), bpf_sk_redirect_map() etc.

Minimum kernel version

The minimum kernel version required to use this feature is 4.14.

Examples

use aya::maps::SockMap;
use aya::programs::SkSkb;

let intercept_ingress = SockMap::try_from(bpf.map("INTERCEPT_INGRESS").unwrap())?;
let map_fd = intercept_ingress.fd().try_clone()?;

let prog: &mut SkSkb = bpf.program_mut("intercept_ingress_packet").unwrap().try_into()?;
prog.load()?;
prog.attach(&map_fd)?;

Implementations

Source

impl<T: Borrow<MapData>> SockMap<T>

pub fn indices(&self) -> MapKeys<'_, u32>

An iterator over the indices of the array that point to a program. The iterator item type is Result<u32, MapError>.

pub fn fd(&self) -> &SockMapFd

Returns the map’s file descriptor.

The returned file descriptor can be used to attach programs that work with socket maps, like SkMsg and SkSkb.

Source

impl<T: BorrowMut<MapData>> SockMap<T>

pub fn set<I: AsRawFd>( &mut self, index: u32, socket: &I, flags: u64, ) -> Result<(), MapError>

Stores a socket into the map.

pub fn clear_index(&mut self, index: &u32) -> Result<(), MapError>

Removes the socket stored at index from the map.

Source

impl<T: Borrow<MapData>> SockMap<T>

pub fn pin<P: AsRef<Path>>(self, path: P) -> Result<(), PinError>

Pins the map to a BPF filesystem.

When a map is pinned it will remain loaded until the corresponding file is deleted. All parent directories in the given path must already exist.