Stack

Struct Stack 

pub struct Stack<T, V: Pod> { /* private fields */ }
A LIFO stack.

Minimum kernel version

The minimum kernel version required to use this feature is 4.20.

Examples

use aya::maps::Stack;

let mut stack = Stack::try_from(bpf.map_mut("STACK").unwrap())?;
stack.push(42, 0)?;
stack.push(43, 0)?;
assert_eq!(stack.pop(0)?, 43);

Implementations

Source

impl<T: Borrow<MapData>, V: Pod> Stack<T, V>

pub fn capacity(&self) -> u32

Returns the number of elements the stack can hold.

This corresponds to the value of bpf_map_def::max_entries on the eBPF side.

Source

impl<T: BorrowMut<MapData>, V: Pod> Stack<T, V>

pub fn pop(&mut self, flags: u64) -> Result<V, MapError>

Removes the last element and returns it.

Errors

Returns MapError::ElementNotFound if the stack is empty, MapError::SyscallError if bpf_map_lookup_and_delete_elem fails.

pub fn push( &mut self, value: impl Borrow<V>, flags: u64, ) -> Result<(), MapError>

Pushes an element on the stack.

Errors

MapError::SyscallError if bpf_map_update_elem fails.

Source

impl<T: Borrow<MapData>, V: Pod> Stack<T, V>

pub fn pin<P: AsRef<Path>>(self, path: P) -> Result<(), PinError>

Pins the map to a BPF filesystem.

When a map is pinned it will remain loaded until the corresponding file is deleted. All parent directories in the given path must already exist.