CgroupSysctl

Struct CgroupSysctl 

pub struct CgroupSysctl { /* private fields */ }
A program used to watch for sysctl changes.

CgroupSysctl programs can be attached to a cgroup and will be called every time a process inside that cgroup tries to read from or write to a sysctl knob in proc.

Minimum kernel version

The minimum kernel version required to use this feature is 5.2.

Examples

use std::fs::File;
use aya::programs::{CgroupAttachMode, CgroupSysctl};

let file = File::open("/sys/fs/cgroup/unified")?;
let program: &mut CgroupSysctl = bpf.program_mut("cgroup_sysctl").unwrap().try_into()?;
program.load()?;
program.attach(file, CgroupAttachMode::Single)?;

Implementations

Source

impl CgroupSysctl

pub fn load(&mut self) -> Result<(), ProgramError>

Loads the program inside the kernel.

pub fn attach<T: AsFd>( &mut self, cgroup: T, mode: CgroupAttachMode, ) -> Result<CgroupSysctlLinkId, ProgramError>

Attaches the program to the given cgroup.

The returned value can be used to detach, see CgroupSysctl::detach.

Takes ownership of the link referenced by the provided link_id.

The link will be detached on Drop and the caller is now responsible for managing its lifetime.

pub fn detach( &mut self, link_id: CgroupSysctlLinkId, ) -> Result<(), ProgramError>

Detaches the program.

See CgroupSysctl::attach.

Source

impl CgroupSysctl

pub fn unload(&mut self) -> Result<(), ProgramError>

Unloads the program from the kernel.

Links will be detached before unloading the program. Note that owned links obtained using take_link() will not be detached.

Source

impl CgroupSysctl

pub fn fd(&self) -> Result<&ProgramFd, ProgramError>

Returns the file descriptor of this Program.

Source

impl CgroupSysctl

pub fn pin<P: AsRef<Path>>(&mut self, path: P) -> Result<(), PinError>

Pins the program to a BPF filesystem.

When a BPF object is pinned to a BPF filesystem it will remain loaded after Aya has unloaded the program. To remove the program, the file on the BPF filesystem must be removed. Any directories in the the path provided should have been created by the caller.

pub fn unpin(self) -> Result<(), Error>

Removes the pinned link from the filesystem.

Source

impl CgroupSysctl

pub fn from_pin<P: AsRef<Path>>(path: P) -> Result<Self, ProgramError>

Creates a program from a pinned entry on a bpffs.

Existing links will not be populated. To work with existing links you should use crate::programs::links::PinnedLink.

On drop, any managed links are detached and the program is unloaded. This will not result in the program being unloaded from the kernel if it is still pinned.

Source

impl CgroupSysctl

pub fn info(&self) -> Result<ProgramInfo, ProgramError>

Returns metadata information of this program.

Uses kernel v4.13 features.