pub enum CgroupAttachMode {
Single,
AllowOverride,
AllowMultiple,
}Expand description
Program attachment mode.
Variants
Single
Allows only one BPF program in the cgroup subtree.
AllowOverride
Allows the program to be overridden by one in a sub-cgroup.
AllowMultiple
Allows multiple programs to be run in the cgroup subtree.