pub struct Array<T, V: Pod> { /* private fields */ }Expand description
A fixed-size array.
The size of the array is defined on the eBPF side using the bpf_map_def::max_entries field.
All the entries are zero-initialized when the map is created.
Minimum kernel version
The minimum kernel version required to use this feature is 3.19.
Examples
use aya::maps::Array;
let mut array = Array::try_from(bpf.map_mut("ARRAY").unwrap())?;
array.set(1, 42, 0)?;
assert_eq!(array.get(&1, 0)?, 42);Implementations
Sourceimpl<T: Borrow<MapData>, V: Pod> Array<T, V>
impl<T: Borrow<MapData>, V: Pod> Array<T, V>
Sourcepub fn len(&self) -> u32
pub fn len(&self) -> u32
Returns the number of elements in the array.
This corresponds to the value of bpf_map_def::max_entries on the eBPF side.
Sourcepub fn get(&self, index: &u32, flags: u64) -> Result<V, MapError>
pub fn get(&self, index: &u32, flags: u64) -> Result<V, MapError>
Returns the value stored at the given index.
Errors
Returns MapError::OutOfBounds if index is out of bounds, MapError::SyscallError
if bpf_map_lookup_elem fails.