pub struct SockMap<T> { /* private fields */ }Expand description
An array of TCP or UDP sockets.
A SockMap is used to store TCP or UDP sockets. eBPF programs can then be
attached to the map to inspect, filter or redirect network buffers on those
sockets.
A SockMap can also be used to redirect packets to sockets contained by the
map using bpf_redirect_map(), bpf_sk_redirect_map() etc.
Minimum kernel version
The minimum kernel version required to use this feature is 4.14.
Examples
use aya::maps::SockMap;
use aya::programs::SkSkb;
let intercept_ingress = SockMap::try_from(bpf.map("INTERCEPT_INGRESS").unwrap())?;
let map_fd = intercept_ingress.fd().try_clone()?;
let prog: &mut SkSkb = bpf.program_mut("intercept_ingress_packet").unwrap().try_into()?;
prog.load()?;
prog.attach(&map_fd)?;
Implementations
Sourceimpl<T: Borrow<MapData>> SockMap<T>
impl<T: Borrow<MapData>> SockMap<T>