pub enum TcAttachOptions {
Netlink(NlOptions),
TcxOrder(LinkOrder),
}Expand description
Options for a SchedClassifier attach operation.
The options vary based on what is supported by the current kernel. Kernels older than 6.6.0 must utilize netlink for attachments, while newer kernels can utilize the modern TCX eBPF link type which supports the kernel’s multi-prog API.
Variants